import { TokenAmount, Price, ChainId } from '@sushiswap/sdk';
import { Message } from './entities/eip712';
import { ethers } from 'ethers';
export interface ILimitOrderData {
    maker: string;
    tokenIn: string;
    tokenOut: string;
    tokenInDecimals: number;
    tokenOutDecimals: number;
    tokenInSymbol: string;
    tokenOutSymbol: string;
    amountIn: string;
    amountOut: string;
    recipient: string;
    startTime: number;
    endTime: number;
    stopPrice?: string;
    oracleAddress?: string;
    oracleData?: string;
    v: number;
    r: string;
    s: string;
    chainId: ChainId;
    orderTypeHash?: String;
}
export declare class LimitOrder {
    readonly maker: string;
    readonly amountIn: TokenAmount;
    readonly amountOut: TokenAmount;
    readonly recipient: string;
    readonly startTime: number;
    readonly endTime: number;
    readonly stopPrice: string;
    readonly oracleAddress: string;
    readonly oracleData: string;
    v: number;
    r: string;
    s: string;
    static getLimitOrder(data: ILimitOrderData): LimitOrder;
    constructor(maker: string, amountIn: TokenAmount, amountOut: TokenAmount, recipient: string, startTime: number, endTime: number, stopPrice?: string, oracleAddress?: string, oracleData?: string, v?: number, r?: string, s?: string);
    get amountInRaw(): string;
    get amountOutRaw(): string;
    get tokenInAddress(): string;
    get tokenOutAddress(): string;
    get tokenInDecimals(): number;
    get tokenOutDecimals(): number;
    get tokenInSymbol(): string;
    get tokenOutSymbol(): string;
    get chainId(): ChainId;
    usePrice(price: Price): LimitOrder;
    signdOrderWithPrivatekey(chainId: ChainId, privateKey: string): {
        v: number;
        r: string;
        s: string;
    };
    signOrderWithProvider(chainId: ChainId, provider: ethers.providers.Web3Provider): Promise<{
        v: number;
        r: string;
        s: string;
    }>;
    getTypedData(): {
        types: {
            EIP712Domain: {
                name: string;
                type: string;
            }[];
            LimitOrder: {
                name: string;
                type: string;
            }[];
        };
        primaryType: string;
        domain: import("./entities/eip712").Domain;
        message: Message;
    };
    getTypeHash(): string;
    send(): Promise<any>;
}
