import { ethers, utils } from 'ethers'
import abi from './entities/bentoboxABI';
import { getSignatureBento, getSignatureWithProviderBentobox } from './entities/eip712'
import { getVerifyingContract } from './constants'
import { ChainId, TokenAmount } from '@sushiswap/sdk'

export async function getApprovalSignature(user: string, nonce: number, chainId: ChainId, privateKey: string) {
    let masterContract = getVerifyingContract(chainId);
    let bentoMessage = {
        warning: 'Give FULL access to funds in (and approved to) BentoBox?',
        user,
        masterContract,
        approved: true,
        nonce
    }
    return await getSignatureBento(bentoMessage, chainId, privateKey);
}

export async function batchApprovalAndDeposit(user: string, chainId: ChainId, nonce: number, token: string, amount: TokenAmount, share: TokenAmount, provider: ethers.providers.Web3Provider) {
    let bentoInterface = new utils.Interface(abi);
    let masterContract = getVerifyingContract(chainId);
    let bentoMessage = {
        warning: 'Give FULL access to funds in (and approved to) BentoBox?',
        user,
        masterContract,
        approved: true,
        nonce
    }
    const { v, r, s } = await getSignatureWithProviderBentobox(bentoMessage, chainId, provider);
    
    let approvalSignatureData = bentoInterface.encodeFunctionData('setMasterContractApproval', [user, masterContract, true, v, r, s]);
    let depositData = bentoInterface.encodeFunctionData('deposit', [token, user, masterContract, amount.raw.toString(), share.raw.toString()]);

    return [approvalSignatureData, depositData];
}